configs property
The List of config for overlapping styles If configs is null, it indicates that the TextSpan does not have a highlighted style
Implementation
final List<HighlightItem>? configs;
The List of config for overlapping styles If configs is null, it indicates that the TextSpan does not have a highlighted style
final List<HighlightItem>? configs;